classdef TimeSig
% Demonstration of the definition of an object to work with the time signal
% contained in a wav file.
% This script is part of the Matlab course for PhD Students 2010-2011:
% http://www.sinnesphysiologie.uni-oldenburg.de/50246.html
% This program was written by Joern Anemueller,
% this version was modified by Jutta Kretzberg, 02.02.2011

    
    %% standard properties that can be read and assigned
    properties
        vData        % measurement data (e.g. sound waveform)
        SampRate     % sampling rate
        sName        % name of the time series
        TimeUnit='s'; 	% unit used for time axis, 
                        % default value is 's' (seconds)
    end
    
    %% "dependent" properties that cannot be assigned directly but are
    % derived from other properties. The value is calculated whenever it is
    % requested.
    properties (Dependent=true)
        vTimeAxis    % time axis in seconds, compute from sampling rate 
                     % and length of the data vector with method
                     % get.vTimeAxis(obj) defined below
    end
    
    %% methods (i.e., functions) that can be applied  
    % to an object of the TimeSig class
    methods
        
        % Constructor method for creating new objects of the class
        function obj = TimeSig(sFileName, sSigName)
            [vX fs]      = wavread(sFileName); % load signal, sampling rate
            obj.vData    = vX;                 % store in object properties
            obj.SampRate = fs;
            obj.sName    = sSigName;
        end
        
        % class method to set the property TimeUnit and restrict values to
        % allowed range
        function obj = set.TimeUnit(obj,timeunit)
            if ~ischar(timeunit)  % wrong class 
                error('TimeUnit must be a string!')
            elseif ~(strcmpi(timeunit,'ms')||strcmpi(timeunit,'s')||...
                    strcmpi(timeunit,'min')||strcmpi(timeunit,'h'))
                    % wrong values
                error('Unknown value for TimeUnit!')
            else
                obj.TimeUnit=timeunit;  % set property to new value
            end
        end
        
        % class method to compute length (number of time points)
        % note that this is different from the matlab built-in length
        % function
        function NPoints = length(obj)
            NPoints = size(obj.vData, 1);
        end
        
        % class method to compute dependent property vTimeAxis
        function vTimeAxis = get.vTimeAxis(obj)
            vTimeAxis = [0:length(obj)-1]/obj.SampRate;
        end
        
        % class method for plotting the object
        % note that this is different from the matlab built-in plot
        % function
        function plot(obj)
            plot(obj.vTimeAxis, obj.vData);   % plot the data
            xlabel(['time [' obj.TimeUnit ']'])  % add x-axis label including
                                                 % TimeUnit
            ylabel('amplitude')               % add y-axis label
            title(obj.sName)                  % add title
        end
        
    end
end
